@@ -11,12 +11,12 @@ from datetime import date, datetime, timedelta
 from telethon.utils import get_display_name
 from telethon.sync import TelegramClient
 from telethon import TelegramClient, functions, types, utils
-import datetime, csv, os, getpass, click, re
+import datetime, requests, json, random, glob, csv, os, getpass, click, re
 import pandas as pd
 
 __author__ = "Jordan Wildon (@jordanwildon)"
 __license__ = "MIT License"
-__version__ = "1.1.10"
+__version__ = "1.1.12"
 __maintainer__ = "Jordan Wildon"
 __email__ = "j.wildon@pm.me"
 __status__ = "Development"
@@ -32,7 +32,6 @@ __status__ = "Development"
 @click.option('--info', '-i', default='', help='Looks up a specified channel by ID.')
 @click.option('--location', '-l', default='', help='Finds users near to specified coordinates.')
 
-
 def cli(verbose,name,archive,media,forwards,participants,user,info,location):
     """Telepathy is an OSINT toolkit for investigating Telegram chats."""
 
@@ -193,13 +192,13 @@ def cli(verbose,name,archive,media,forwards,participants,user,info,location):
                 client.loop.run_until_complete(main())
 
     if forwards:
-        directory = './' + alphanumeric + '/edgelists/'
+        f_directory = directory + alphanumeric + '/edgelists/'
         try:
-            os.makedirs(directory)
+            os.makedirs(f_directory)
         except FileExistsError:
             pass
 
-        file = directory + alphanumeric + '_edgelist.csv'
+        file = f_directory + alphanumeric + '_edgelist.csv'
         for n in name:
             async def main():
                 click.echo('Listing forwards from {n}'.format(n))
@@ -318,13 +317,13 @@ def cli(verbose,name,archive,media,forwards,participants,user,info,location):
 
     if participants:
 
-        directory = './memberlists'
+        p_directory = directory + 'memberlists'
         try:
             os.makedirs(directory)
         except FileExistsError:
             pass
 
-        file_name = "./memberlists/"+alphanumeric+"_members.csv"
+        file_name = p_directory + alphanumeric + "_members.csv"
         for n in name:
             click.echo('Fetching members for {0}'.format(n))
             async def main():
@@ -426,6 +425,5 @@ def cli(verbose,name,archive,media,forwards,participants,user,info,location):
         total = len(l)
         click.echo(total,'users found')
 
-
 if __name__ == '__main__':
     cli()
